==> pentest_helper-0.0.1.tar.gz: pentest_helper-0.0.1/README.md <==
# pentest_helper
Quick scripts that helps me during a pentest assessment and OSCP exams to initiate
folder structure and running basic commands like nmap.

## Instalation

```bash
pipx install pentest_helper
```

## Usage

### Initiating folder structure

```bash
# Create a new mission structure
pentest_helper init oscp_boxes --hosts 1.1.1.1 2.2.2.2

# Showing the created structure
tree oscp_boxes/
oscp_boxes/
├── cmd_outputs
├── custom_rockyou.txt
├── exclude_scope.txt
├── hosts
│   ├── 1.1.1.1
│   │   ├── loots
│   │   ├── ntlm_hashes.txt
│   │   ├── passwords.txt
│   │   ├── scans
│   │   │   └── nmap
│   │   ├── userntlmhashes.txt
│   │   ├── userpass.txt
│   │   ├── users.txt
│   │   └── wordlist.txt
│   └── 2.2.2.2
│       ├── loots
│       ├── ntlm_hashes.txt
│       ├── passwords.txt
│       ├── scans
│       │   └── nmap
│       ├── userntlmhashes.txt
│       ├── userpass.txt
│       ├── users.txt
│       └── wordlist.txt
├── ip
│   └── all.ip.txt
├── loots
├── notes.md
├── ntlm_hashes.txt
├── passwords.txt
├── scans
│   └── nmap
├── scope.txt
├── screenshots
├── userntlmhashes.txt
├── userpass.txt
├── users.txt
└── wordlist.txt

15 directories, 23 files


# Adding a new host
cd oscp_boxes
pentest_helper init_host 3.3.3.3

# Show new structure
tree

├── cmd_outputs
├── custom_rockyou.txt
├── exclude_scope.txt
├── hosts
│   ├── 1.1.1.1
│   │   ├── loots
│   │   ├── ntlm_hashes.txt
│   │   ├── passwords.txt
│   │   ├── scans
│   │   │   └── nmap
│   │   ├── userntlmhashes.txt
│   │   ├── userpass.txt
│   │   ├── users.txt
│   │   └── wordlist.txt
│   ├── 2.2.2.2
│   │   ├── loots
│   │   ├── ntlm_hashes.txt
│   │   ├── passwords.txt
│   │   ├── scans
│   │   │   └── nmap
│   │   ├── userntlmhashes.txt
│   │   ├── userpass.txt
│   │   ├── users.txt
│   │   └── wordlist.txt
│   └── 3.3.3.3
│       ├── loots
│       ├── ntlm_hashes.txt
│       ├── passwords.txt
│       ├── scans
│       │   └── nmap
│       ├── userntlmhashes.txt
│       ├── userpass.txt
│       ├── users.txt
│       └── wordlist.txt
├── ip
│   └── all.ip.txt
├── loots
├── notes.md
├── ntlm_hashes.txt
├── passwords.txt
├── scans
│   └── nmap
├── scope.txt
├── screenshots
├── userntlmhashes.txt
├── userpass.txt
├── users.txt
└── wordlist.txt

19 directories, 29 files
```

==> pentest_helper-0.0.2.tar.gz: pentest_helper-0.0.2/README.md <==
# pentest_helper
Quick scripts that helps me during a pentest assessment and OSCP exams to initiate
folder structure and running basic commands like nmap.

## Instalation

```bash
sudo PIPX_BIN_DIR=/usr/local/bin pipx install pentest_helper
```

## Usage

### Initiating folder structure

```bash
# Create a new mission structure
pentest_helper init oscp_boxes --hosts 1.1.1.1 2.2.2.2

# Showing the created structure
tree oscp_boxes/
oscp_boxes/
├── cmd_outputs
├── custom_rockyou.txt
├── exclude_scope.txt
├── hosts
│   ├── 1.1.1.1
│   │   ├── loots
│   │   ├── ntlm_hashes.txt
│   │   ├── passwords.txt
│   │   ├── scans
│   │   │   └── nmap
│   │   ├── userntlmhashes.txt
│   │   ├── userpass.txt
│   │   ├── users.txt
│   │   └── wordlist.txt
│   └── 2.2.2.2
│       ├── loots
│       ├── ntlm_hashes.txt
│       ├── passwords.txt
│       ├── scans
│       │   └── nmap
│       ├── userntlmhashes.txt
│       ├── userpass.txt
│       ├── users.txt
│       └── wordlist.txt
├── ip
│   └── all.ip.txt
├── loots
├── notes.md
├── ntlm_hashes.txt
├── passwords.txt
├── scans
│   └── nmap
├── scope.txt
├── screenshots
├── userntlmhashes.txt
├── userpass.txt
├── users.txt
└── wordlist.txt

15 directories, 23 files


# Adding a new host
cd oscp_boxes
pentest_helper init_host 3.3.3.3

# Show new structure
tree

├── cmd_outputs
├── custom_rockyou.txt
├── exclude_scope.txt
├── hosts
│   ├── 1.1.1.1
│   │   ├── loots
│   │   ├── ntlm_hashes.txt
│   │   ├── passwords.txt
│   │   ├── scans
│   │   │   └── nmap
│   │   ├── userntlmhashes.txt
│   │   ├── userpass.txt
│   │   ├── users.txt
│   │   └── wordlist.txt
│   ├── 2.2.2.2
│   │   ├── loots
│   │   ├── ntlm_hashes.txt
│   │   ├── passwords.txt
│   │   ├── scans
│   │   │   └── nmap
│   │   ├── userntlmhashes.txt
│   │   ├── userpass.txt
│   │   ├── users.txt
│   │   └── wordlist.txt
│   └── 3.3.3.3
│       ├── loots
│       ├── ntlm_hashes.txt
│       ├── passwords.txt
│       ├── scans
│       │   └── nmap
│       ├── userntlmhashes.txt
│       ├── userpass.txt
│       ├── users.txt
│       └── wordlist.txt
├── ip
│   └── all.ip.txt
├── loots
├── notes.md
├── ntlm_hashes.txt
├── passwords.txt
├── scans
│   └── nmap
├── scope.txt
├── screenshots
├── userntlmhashes.txt
├── userpass.txt
├── users.txt
└── wordlist.txt

19 directories, 29 files
```
